@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0509';
+our $VERSION = '0.0510';
 
 use Moo;
 use strictures 2;
@@ -220,12 +220,12 @@ sub generate {
 
     # Choose the right note given the scale if the tonic is set
     if ($self->tonic) {
-        my $key = @chosen == 1 ? $chosen[0] : $chosen[1];
+        my $ckey = @chosen == 1 ? $chosen[0] : $chosen[1];
         if ($scale eq 'pentatonic' || $scale eq 'pminor') {
-            $chosen[0] = _closest($key, [ @fixed[0,1,2] ])
+            $chosen[0] = _closest($ckey, [ @fixed[0,1,2] ])
         }
         elsif (@fixed == 7) { # standard, 7-note Western scale
-            $chosen[0] = _closest($key, [ @fixed[0,2,4] ])
+            $chosen[0] = _closest($ckey, [ @fixed[0,2,4] ])
         }
     }
 
@@ -300,7 +300,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0509
+version 0.0510
 
 =head1 SYNOPSIS
 
